@@ -9,7 +9,8 @@ alfa.contour <- function(m, s, a, n = 100, x = NULL, cont.line = FALSE) {
   x1 <- seq(0.001, 0.999, length = n)
   sqrt3 <- sqrt(3)
   x2 <- seq(0.001, sqrt3/2 - 0.001, length = n)
-  #suppressWarnings()
+  oop <- options( warn = -1 )
+  on.exit( options(oop) )
 
   wa <- NULL
   for ( i in 1:n ) {
